@@ -1,7 +1,8 @@
 pub use crate::database::*;
 pub use crate::macros::*;
 pub use crate::protobuf::*;
-pub use crate::register_schemas;
 pub use crate::register_services;
 pub use crate::schema::*;
 pub use crate::service::*;
+pub use chrono::{DateTime, FixedOffset};
+pub use uuid::Uuid;
